@@ -4,12 +4,6 @@ These roles are useful for temporarily adding semantically-markedup
 APIs while waiting for the API reference itself to be added.
 """
 
-from __future__ import (division, absolute_import, print_function,
-                        unicode_literals)
-from builtins import *  # NOQA
-from future.standard_library import install_aliases
-install_aliases()  # NOQA
-
 import logging
 
 from docutils import nodes
